#
# spec file for package sdl-ball
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
# Copyright Vincent Petry <PVince81@yahoo.fr>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           sdl-ball
Version:        1.02
Release:        2.3
Summary:        A Free/OpenSource brick-breaking game with pretty graphics
License:        GPL-3.0
Group:          Amusements/Games/Action/Breakout
Url:            http://dustedgames.blogspot.co.uk/p/sdl-ball_20.html
Source0:        http://downloads.sourceforge.net/%{name}/%{version}/%{name}-%{version}.tar.bz2
Source1:        %{name}.sh
# PATCH-FIX-UPSTREAM https://sourceforge.net/p/sdl-ball/patches/5/
Patch0:         %{name}-%{version}-sdl-ball.desktop.patch
%if 0%{?suse_version}
BuildRequires:  fdupes
BuildRequires:  update-desktop-files
%endif
BuildRequires:  dos2unix
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig(SDL_image)
BuildRequires:  pkgconfig(SDL_mixer)
BuildRequires:  pkgconfig(SDL_ttf)
BuildRequires:  pkgconfig(sdl)

%description
SDL-Ball is a Free/OpenSource brick-breaking game with pretty graphics.
It is written in C++ using SDL and OpenGL.

Your mission: To smash your way through a series of progressively harder
and more tricky levels. Your tools: Ultrakinetic titanium balls and your
trusty Gruntmazter-3000-Paddle edition.

Features:
* 50 levels.
* OpenGL eye candy. (Nice graphics, really)
* Lots of powerups and powerdowns.
* Powerup Shop - You get special coins for collecting powerups,
  you can spend them on more powerups.
* Highscores.
* Sound.
* Easy to use level editor.
* Themes - Selectable from options menu.
  Themes support loading new gfx,snd and levels.
  A theme can be partial, if a file is missing,
  it will be loaded from the default theme.
  You can even mix between gfx,snd and level themes!
* Controllable with Mouse/Keyboard/Joystick and WiiMote.
* Save and Load games
* Cool Introscreen
* Screenshot function

%prep
%setup -q

# Convert to unix line end
find . -name "*.cpp" -exec dos2unix "{}" "+"

%patch0

%build
export CFLAGS="%{optflags}"
make %{?_smp_mflags}

%install
# install wrapper
install -Dm 0755 %{S:1} %{buildroot}%{_bindir}/%{name}

# install executable
install -Dm 0755 %{name} %{buildroot}%{_libexecdir}/%{name}/%{name}

# install directories
mkdir -p %{buildroot}%{_libexecdir}/%{name}/themes/{default,dio-sound-theme}
for d in default dio-sound-theme ; do
    cp -a themes/$d %{buildroot}%{_libexecdir}/%{name}/themes/
done

# install icon
install -Dm 0644 themes/default/icon32.png %{buildroot}%{_datadir}/pixmaps/%{name}.png

# install Desktop file
install -Dm 0644 %{name}.desktop %{buildroot}%{_datadir}/applications/%{name}.desktop

%if 0%{?suse_version}
    %suse_update_desktop_file %{name}
    %fdupes -s %{buildroot}%{_prefix}
%endif

%files
%defattr(-,root,root,-)
%doc LICENSE.txt README
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/pixmaps/%{name}.png
%{_libexecdir}/%{name}

%changelog
* Fri Nov  7 2014 nemysis@gmx.ch
- Update to 1.02, announce message is here:
    http://dustedgames.blogspot.co.uk/2014/10/gosh-sdl-ball-was-updated.html
- Change URL
- Remove Desktop entry file and png, use supplied
- Remove obsolete patches sdl-ball-dontstrip.patch,
  sdl-ball-gcc47.patch and sdl-ball-gcc48.patch, changed by upstream
- Remove obsolete patch sdl-ball-makefile.patch, not accepted by
  upstream
- Remove BuildRequires for Mesa-devel
- Use BuildRequires pkgconfig(SDL_image), pkgconfig(SDL_mixer),
  pkgconfig(SDL_ttf) and pkgconfig(sdl) instead of libSDL-devel,
  libSDL_image-devel, libSDL_mixer-devel and libSDL_ttf-devel
- Add BuildRequires for dos2unix
- Change description
- Add patch sdl-ball-1.02-sdl-ball.desktop.patch
- Use %%{_libexecdir} instead of {_datadir}, because not good Makefile
- Add sdl-ball.sh, that game works from datadir
- Use symlink for %%fdupes
* Sun Feb  9 2014 dap.darkness@gmail.com
- Added sdl-ball-gcc48.patch from Debian Sid
  to build for openSUSE 13.1 & Factory.
* Thu May 24 2012 joop.boonen@opensuse.org
- Created a gcc47 patch and a don't strip for debug patch
- Cleaned spec file up
* Sun Mar 25 2012 jengelh@medozas.de
- Parallel build with %%_smp_mflags; strip redundant spec sections
- Avoid service downloading a new tarball
* Tue Jul 14 2009 PVince81@yahoo.fr
- Changed installation paths
* Fri Jul  3 2009 PVince81@yahoo.fr
- Moved binary from /usr/bin to /usr/games
* Fri Jun 19 2009 PVince81@yahoo.fr
- Fixed libSDL build dependency
* Thu May 21 2009 PVince81@yahoo.fr
- fixed rpm description to be displayed properly in yast
* Sat May  9 2009 PVince81@yahoo.fr
- added missing RPM_OPT_FLAGS
* Wed May  6 2009 PVince81@yahoo.fr
- created package (version 1.01)
